Varying the Number of Colors
----------------------------

The number of states, or colors, that a cell can adopt is given by `k`. For example, a binary cellular automaton, in which a cell can assume only values of 0 and 1, has `k = 2`. CellPyLib3d supports any value of `k`. 